@@ -1,12 +1,10 @@
 try:
     from normatrix.source.file_parser import CFileParse
     from normatrix.source.file_parser import TypeLine
-except:
+except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
     from normatrix.normatrix.source.file_parser import TypeLine
 
-import re
-
 def check(file: CFileParse) -> (int, int):
     nb_error = 0
     last_is_no = False
