@@ -26,15 +26,15 @@ smart_match = {
 }
 
 OPERATOR_LIST = [
-        (' ([+', '+', '+])= '),
-        (' ([-', '-', '-])=> '),
-        (' ([/*', '*', ':NOTHING:'),
-        (' (/*', '/', '*/= '),
-        ('< ', '<', ':ALL:'),
-        (':ALL:', '>', ' >='),
-        (' ', '&', ':ALL:'),
-        ('([ ', '!', ':ALL:'),
-        ('/+*-=! ', '=', '= '),
-        (':ALL:', '(', ':ALL:'),
-        (':ALL:', ')', '}]) ;')
+        (' ([+',    '+',    '+])= '),
+        (' ([-',    '-',    '-])=> '),
+        (' ([/*',   '*',    ':NOTHING:',    '[\[\{\( ]\*{2,}'),
+        (' (/*',    '/',    '*/= ',         '<\w+?\/\w+?\.h>'),
+        ('< ',      '<',    ':ALL:'),
+        (':ALL:',   '>',    ' >='),
+        (' ',       '&',    ':ALL:'),
+        ('([ ',     '!',    ':ALL:'),
+        ('/+*-=! ', '=',    '= '),
+        (':ALL:',   '(',    ':ALL:'),
+        (':ALL:',   ')',    '}]) ;')
 ]
